@@ -1,13 +1,14 @@
 #' Following Codes
-#' 
+#'
 #' Identifies sequences of codes that follow each other from time domain signal analysis, and optionally plots them as a Sankey diagram.
-#' 
+#'
 #' @param tdsc A TDSC object
 #' @param depth The length of the sequence of codes to search for
 #' @param min_code The minimum value of code to include in sequence
 #' @param max_code The maximum value of code to include in sequence
 #' @param colourCode If plot is alluvial, colour all codes following this code
 #' @param plot If "alluvial" plots the found sequences in a river plot
+#' @param ... Arguments to pass to the plotting function
 #' @keywords TDSC
 #' @export
 #' @examples
@@ -18,12 +19,13 @@
 #' followingCodes(t)
 #' followingCodes(t, colourCode=2,plot="alluvial")
 #' }
-followingCodes <- function (tdsc, 
-                             depth=2, 
-                             min_code=0, 
+followingCodes <- function (tdsc,
+                             depth=2,
+                             min_code=0,
                              max_code=10,
                              colourCode=1,
-                             plot=F) {
+                             plot=F,
+                             ...) {
   codelist <- tdsc@codelist
   fs <- c()
   p <- cbind(min_code:max_code)
@@ -46,10 +48,10 @@ followingCodes <- function (tdsc,
       }
     }
     p <- p_found
-    
+
   }
   colnames(fs) <- c(paste0(rep("Code", depth+1), 1:(depth+1)), "Freq")
-  
+
   if (plot=="alluvial") {
     if (!requireNamespace("alluvial", quietly=TRUE)) {
       stop()
@@ -58,8 +60,9 @@ followingCodes <- function (tdsc,
     alluvial::alluvial( f[,1:(depth+1)], freq=f$Freq, border=NA,
                         hide = f$Freq < stats::quantile(f$Freq, .50),
                         col=ifelse( f$Code1 == colourCode,
-                                    "red", "grey") 
+                                    "red", "grey"),
+                        ...
     )
   }
   return(fs)
-}
\ No newline at end of file
+}
